Django Grappelli
================

**A jazzy skin for the Django admin interface**.

Grappelli is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

Code
----

https://github.com/sehmaschine/django-grappelli

Documentation
-------------

http://readthedocs.org/docs/django-grappelli/

Releases
--------

**Grappelli is always developed against the latest stable Django release and is NOT tested with Djangos trunk.**

* Grappelli 2.6.3 (November 14th, 2014): Compatible with Django 1.7
* Grappelli 2.5.6 (November 14th, 2014): Compatible with Django 1.6
* Grappelli 2.4.12 (November 14th, 2014): Compatible with Django 1.4/1.5

Current development branches:

* Grappelli 2.6.4 (Development version for Django 1.7, see branch Stable/2.6.x)
* Grappelli 2.5.7 (Development version for Django 1.6, see branch Stable/2.5.x)
* Grappelli 2.4.13 (Development version for Django 1.4/1.5, see branch Stable/2.4.x)

Older versions are available at GitHub, but are not supported anymore.
Support for 2.4.x and 2.5.x is limited to security issues and very important bugfixes.